==> haskell-aeson-compat-0.3.9-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-compat
version:              0.3.9
visibility:           public
id:                   aeson-compat-0.3.9-2Ylt1dDW4Dm3ur50kYFq5h
key:                  aeson-compat-0.3.9-2Ylt1dDW4Dm3ur50kYFq5h
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/aeson-compat#readme
synopsis:             Compatibility layer for aeson
description:          Compatibility layer for @aeson@
category:             Web
abi:                  07859f35f1d9b4fceeb96de23499696e
exposed:              True
exposed-modules:      Data.Aeson.Compat
import-dirs:          /usr/lib/ghc-8.10.2/site-local/aeson-compat-0.3.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/aeson-compat-0.3.9
hs-libraries:         HSaeson-compat-0.3.9-2Ylt1dDW4Dm3ur50kYFq5h
depends:
    aeson-1.5.4.1-4wEKZPgDVdkFlnmRCF3GfK
    attoparsec-0.13.2.4-BkYo3BeI9ab9OAiwbGneKH
    attoparsec-iso8601-1.0.1.0-23Yx2hxyTLOl5hHQBnFN base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.10.0
    containers-0.6.2.1 exceptions-0.10.4
    hashable-1.3.0.0-1qHAALw6V3KFC8KcGIO5Ie
    scientific-0.3.6.2-GYJ9xIed9KtBuzeH6CTmVU
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-7jajDWNmlIpBHz95ShzOz6
    vector-0.12.1.2-2RftPi1Wv2O9pWjpJnOFtm

haddock-interfaces:
    /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock

haddock-html:         /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.9-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-compat
version:              0.3.9
visibility:           public
id:                   aeson-compat-0.3.9-5iimtbalvdKFYkto1VPkSt
key:                  aeson-compat-0.3.9-5iimtbalvdKFYkto1VPkSt
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/aeson-compat#readme
synopsis:             Compatibility layer for aeson
description:          Compatibility layer for @aeson@
category:             Web
abi:                  f68fb8681227f11585fb911f15805e2d
exposed:              True
exposed-modules:      Data.Aeson.Compat
import-dirs:          /usr/lib/ghc-8.10.2/site-local/aeson-compat-0.3.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/aeson-compat-0.3.9
hs-libraries:         HSaeson-compat-0.3.9-5iimtbalvdKFYkto1VPkSt
depends:
    aeson-1.5.4.1-7Fmt2H1B65wDOTuTXG6T4t
    attoparsec-0.13.2.4-A3iUKuJR7UBHxmP0AEJfvQ
    attoparsec-iso8601-1.0.1.0-B0PnDcWCMwkKRwXVVufkMo base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.10.0
    containers-0.6.2.1 exceptions-0.10.4
    hashable-1.3.0.0-JPCB4MmZaOcIaoM3ucdjgC
    scientific-0.3.6.2-Ip3ggXxxNwm3oywsJ3ZDCs
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-2nDlvtn1IciJcNnZKP7xpJ
    vector-0.12.1.2-DniijS7i95iDT0VwtGN3m0

haddock-interfaces:
    /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock

haddock-html:         /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
